@@ -55,6 +55,12 @@ from bluetooth_mesh.messages.silvair.gateway_config_server import (
     GatewayConfigServerOpcode,
     GatewayConfigServerSubOpcode,
 )
+from bluetooth_mesh.messages.silvair.light_extended_controller import (
+    LightExtendedControllerMessage,
+    LightExtendedControllerOpcode,
+    LightExtendedControllerProperty,
+    LightExtendedControllerSubOpcode,
+)
 from bluetooth_mesh.messages.silvair.network_diagnostic_server import (
     NetworkDiagnosticServerOpcode,
     NetworkDiagnosticSetupServerOpcode,
@@ -81,6 +87,7 @@ __all__ = [
     "LightCTLClient",
     "GatewayConfigServer",
     "GatewayConfigClient",
+    "LightExtendedControllerSetupClient",
 ]
 
 AppKeyStatus = NamedTuple(
@@ -824,6 +831,8 @@ class HealthServer(Model):
         HealthOpcode.ATTENTION_SET,
         HealthOpcode.ATTENTION_SET_UNACKNOWLEDGED,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
 
 class HealthClient(Model):
@@ -834,6 +843,8 @@ class HealthClient(Model):
         HealthOpcode.PERIOD_STATUS,
         HealthOpcode.ATTENTION_STATUS,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
     async def attention(self, destination: int, app_index: int, attention: int) -> int:
         status = self.expect_app(
@@ -872,6 +883,8 @@ class DebugServer(Model):
     OPCODES = {
         DebugOpcode.OPCODE,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
 
 class DebugClient(Model):
@@ -879,6 +892,8 @@ class DebugClient(Model):
     OPCODES = {
         DebugOpcode.OPCODE,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
     async def get_param(
         self,
@@ -905,7 +920,7 @@ class DebugClient(Model):
         statuses = {
             node: self.expect_dev(
                 node,
-                net_index=0,
+                net_index=net_index,
                 opcode=DebugOpcode.OPCODE,
                 params=dict(subopcode=status),
             )
@@ -1059,6 +1074,8 @@ class NetworkDiagnosticClient(Model):
     OPCODES = {
         NetworkDiagnosticServerOpcode.OPCODE,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
 
 class NetworkDiagnosticSetupClient(Model):
@@ -1066,6 +1083,7 @@ class NetworkDiagnosticSetupClient(Model):
     OPCODES = {
         NetworkDiagnosticSetupServerOpcode.OPCODE,
     }
+    PUBLISH = True
 
 
 class GenericOnOffServer(Model):
@@ -1075,6 +1093,8 @@ class GenericOnOffServer(Model):
         GenericOnOffOpcode.ONOFF_SET,
         GenericOnOffOpcode.ONOFF_SET_UNACKNOWLEDGED,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
 
 class GenericOnOffClient(Model):
@@ -1082,6 +1102,8 @@ class GenericOnOffClient(Model):
     OPCODES = {
         GenericOnOffOpcode.ONOFF_STATUS,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
     _tid = 0
 
     @property
@@ -1222,6 +1244,8 @@ class SceneClient(Model):
         SceneOpcode.SCENE_DELETE,
         SceneOpcode.SCENE_DELETE_UNACKNOWLEDGED,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
     def __init__(self, element: "Element"):
         super().__init__(element)
@@ -1257,6 +1281,48 @@ class SceneClient(Model):
             request, retransmissions=6, send_interval=values["send_interval"]
         )
 
+    async def get_scene(
+        self,
+        nodes: Sequence[int],
+        app_index: int,
+        *,
+        send_interval: float = 0.1,
+        timeout: Optional[float] = None,
+    ):
+        requests = {
+            node: partial(
+                self.send_app,
+                node,
+                app_index=app_index,
+                opcode=SceneOpcode.SCENE_GET,
+                params=dict(),
+            )
+            for node in nodes
+        }
+
+        statuses = {
+            node: self.expect_app(
+                node,
+                app_index=0,
+                destination=None,
+                opcode=SceneOpcode.SCENE_STATUS,
+                params=dict(),
+            )
+            for node in nodes
+        }
+
+        results = await self.bulk_query(
+            requests,
+            statuses,
+            send_interval=send_interval,
+            timeout=timeout or len(nodes) * 0.5,
+        )
+
+        return {
+            node: None if isinstance(result, Exception) else result["params"]
+            for node, result in results.items()
+        }
+
 
 class GenericLevelClient(Model):
     MODEL_ID = (None, 0x1003)
@@ -1269,6 +1335,8 @@ class GenericLevelClient(Model):
         GenericLevelOpcode.MOVE_SET,
         GenericLevelOpcode.MOVE_SET_UNACKNOWLEDGED,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
     def __init__(self, element: "Element"):
         super().__init__(element)
@@ -1319,6 +1387,8 @@ class LightLightnessServer(Model):
         LightLightnessOpcode.LIGHTNESS_SET_UNACKNOWLEDGED,
         LightLightnessOpcode.LIGHTNESS_STATUS,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
 
 class LightLightnessSetupServer(Model):
@@ -1329,6 +1399,7 @@ class LightLightnessSetupServer(Model):
         LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET,
         LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED,
     }
+    SUBSCRIBE = True
 
 
 class LightLightnessClient(Model):
@@ -1340,6 +1411,8 @@ class LightLightnessClient(Model):
         LightLightnessOpcode.LIGHTNESS_STATUS,
         LightLightnessSetupOpcode.LIGHTNESS_RANGE_SET_UNACKNOWLEDGED,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
     _tid = 0
 
     @property
@@ -1468,6 +1541,8 @@ class SensorClient(Model):
         SensorOpcode.SENSOR_GET,
         SensorOpcode.SENSOR_STATUS,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
 
 class LightCTLClient(Model):
@@ -1486,6 +1561,8 @@ class LightCTLClient(Model):
         LightCTLOpcode.CTL_TEMPERATURE_DEFAULT_GET,
         LightCTLOpcode.CTL_TEMPERATURE_DEFAULT_STATUS,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
     _tid = 0
 
     @property
@@ -1586,6 +1663,8 @@ class GatewayConfigServer(Model):
     OPCODES = {
         GatewayConfigServerOpcode.OPCODE,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
     def send_configuration_status(
         self,
@@ -1647,6 +1726,8 @@ class GatewayConfigClient(Model):
     OPCODES = {
         GatewayConfigServerOpcode.OPCODE,
     }
+    PUBLISH = True
+    SUBSCRIBE = True
 
     async def configuration_get(self, destination: int, net_index: int):
         request = partial(
@@ -1948,3 +2029,97 @@ class GatewayConfigClient(Model):
             ),
         )
         return await self.query(request, status, timeout=1.0)
+
+
+class LightExtendedControllerSetupClient(Model):
+    MODEL_ID = (0x0136, 0x0012)
+    OPCODES = {
+        LightExtendedControllerOpcode.OPCODE,
+    }
+    PUBLISH = False
+    SUBSCRIBE = True
+
+    async def get_property(
+        self,
+        nodes: Iterable[int],
+        net_index: int,
+        property_id: int,
+        *,
+        send_interval: float = 1.0,
+        progress_callback: Optional[ProgressCallback] = None,
+        timeout: Optional[float] = None,
+    ) -> Dict[int, Optional[Any]]:
+        requests = {
+            node: partial(
+                self.send_dev,
+                node + 1,
+                net_index=net_index,
+                opcode=LightExtendedControllerOpcode.OPCODE,
+                params=dict(
+                    subopcode=LightExtendedControllerSubOpcode.PROPERTY_GET,
+                    payload=dict(id=property_id),
+                ),
+            )
+            for node in nodes
+        }
+
+        statuses = {
+            node: self.expect_dev(
+                node + 1,
+                net_index=net_index,
+                opcode=LightExtendedControllerOpcode.OPCODE,
+                params=dict(
+                    subopcode=LightExtendedControllerSubOpcode.PROPERTY_STATUS,
+                    payload=dict(id=property_id),
+                )
+            )
+            for node in nodes
+        }
+
+        async def _progress_callback(address, result, done, total):
+            if isinstance(result, TimeoutError):
+                self.logger.warning("Callback timeout for addr %s", address)
+                return
+
+            try:
+                aw = progress_callback(address, result["params"]["data"], done, total)
+
+                if inspect.isawaitable(aw):
+                    await aw
+            except Exception as ex:
+                self.logger.warning("Callback failed for addr %s: %s", address, ex)
+
+        results = await self.bulk_query(
+            requests,
+            statuses,
+            send_interval=send_interval,
+            timeout=timeout,
+            progress_callback=_progress_callback if progress_callback else None,
+        )
+
+        return {
+            node: None if isinstance(result, Exception) else result["params"]["payload"]["value"]
+            for node, result in results.items()
+        }
+
+    async def get_auto_resume_mode(
+        self, nodes: Sequence[int], net_index: int
+    ) -> Dict[int, Optional[Any]]:
+        return await self.get_property(
+            nodes,
+            net_index,
+            LightExtendedControllerProperty.AUTO_RESUME_MODE,
+            send_interval=0.1,
+            timeout=len(nodes) * 0.5,
+        )
+
+    async def get_auto_resume_timer(
+        self, nodes: Sequence[int], net_index: int
+    ) -> Dict[int, Optional[Any]]:
+        return await self.get_property(
+            nodes,
+            net_index,
+            LightExtendedControllerProperty.AUTO_RESUME_TIMER,
+            send_interval=0.1,
+            timeout=len(nodes) * 0.5,
+        )
